Struct amazon_sp_orders::models::order_item::OrderItem
source · [−]pub struct OrderItem {Show 34 fields
pub ASIN: String,
pub seller_sku: Option<String>,
pub order_item_id: String,
pub title: Option<String>,
pub quantity_ordered: i32,
pub quantity_shipped: Option<i32>,
pub product_info: Option<Box<ProductInfoDetail>>,
pub points_granted: Option<Box<PointsGrantedDetail>>,
pub item_price: Option<Box<Money>>,
pub shipping_price: Option<Box<Money>>,
pub item_tax: Option<Box<Money>>,
pub shipping_tax: Option<Box<Money>>,
pub shipping_discount: Option<Box<Money>>,
pub shipping_discount_tax: Option<Box<Money>>,
pub promotion_discount: Option<Box<Money>>,
pub promotion_discount_tax: Option<Box<Money>>,
pub promotion_ids: Option<Vec<String>>,
pub cod_fee: Option<Box<Money>>,
pub cod_fee_discount: Option<Box<Money>>,
pub is_gift: Option<bool>,
pub condition_note: Option<String>,
pub condition_id: Option<String>,
pub condition_subtype_id: Option<String>,
pub scheduled_delivery_start_date: Option<String>,
pub scheduled_delivery_end_date: Option<String>,
pub price_designation: Option<String>,
pub tax_collection: Option<Box<TaxCollection>>,
pub serial_number_required: Option<bool>,
pub is_transparency: Option<bool>,
pub ioss_number: Option<String>,
pub store_chain_store_id: Option<String>,
pub deemed_reseller_category: Option<DeemedResellerCategory>,
pub buyer_info: Option<Box<ItemBuyerInfo>>,
pub buyer_requested_cancel: Option<Box<BuyerRequestedCancel>>,
}Expand description
OrderItem : A single order item.
Fields
ASIN: StringThe Amazon Standard Identification Number (ASIN) of the item.
seller_sku: Option<String>The seller stock keeping unit (SKU) of the item.
order_item_id: StringAn Amazon-defined order item identifier.
title: Option<String>The name of the item.
quantity_ordered: i32The number of items in the order.
quantity_shipped: Option<i32>The number of items shipped.
product_info: Option<Box<ProductInfoDetail>>points_granted: Option<Box<PointsGrantedDetail>>item_price: Option<Box<Money>>shipping_price: Option<Box<Money>>item_tax: Option<Box<Money>>shipping_tax: Option<Box<Money>>shipping_discount: Option<Box<Money>>shipping_discount_tax: Option<Box<Money>>promotion_discount: Option<Box<Money>>promotion_discount_tax: Option<Box<Money>>promotion_ids: Option<Vec<String>>A list of promotion identifiers provided by the seller when the promotions were created.
cod_fee: Option<Box<Money>>cod_fee_discount: Option<Box<Money>>is_gift: Option<bool>When true, the item is a gift.
condition_note: Option<String>The condition of the item as described by the seller.
condition_id: Option<String>The condition of the item. Possible values: New, Used, Collectible, Refurbished, Preorder, Club.
condition_subtype_id: Option<String>The subcondition of the item. Possible values: New, Mint, Very Good, Good, Acceptable, Poor, Club, OEM, Warranty, Refurbished Warranty, Refurbished, Open Box, Any, Other.
scheduled_delivery_start_date: Option<String>The start date of the scheduled delivery window in the time zone of the order destination. In ISO 8601 date time format.
scheduled_delivery_end_date: Option<String>The end date of the scheduled delivery window in the time zone of the order destination. In ISO 8601 date time format.
price_designation: Option<String>Indicates that the selling price is a special price that is available only for Amazon Business orders. For more information about the Amazon Business Seller Program, see the Amazon Business website. Possible values: BusinessPrice - A special price that is available only for Amazon Business orders.
tax_collection: Option<Box<TaxCollection>>serial_number_required: Option<bool>When true, the product type for this item has a serial number. Returned only for Amazon Easy Ship orders.
is_transparency: Option<bool>When true, transparency codes are required.
ioss_number: Option<String>The IOSS number for the marketplace. Sellers shipping to the European Union (EU) from outside of the EU must provide this IOSS number to their carrier when Amazon has collected the VAT on the sale.
store_chain_store_id: Option<String>The store chain store identifier. Linked to a specific store in a store chain.
deemed_reseller_category: Option<DeemedResellerCategory>The category of deemed reseller. This applies to selling partners that are not based in the EU and is used to help them meet the VAT Deemed Reseller tax laws in the EU and UK.
buyer_info: Option<Box<ItemBuyerInfo>>buyer_requested_cancel: Option<Box<BuyerRequestedCancel>>